pub struct ThumbnailQuery {
pub id: String,
pub pid: Option<String>,
pub width: Option<u32>,
pub height: Option<u32>,
pub padding: Option<u32>,
pub crop: Option<CropMode>,
}Expand description
Query parameters for the Bing thumbnail endpoint.
Fields
id: StringImage identifier.
pid: Option<String>Page identifier.
width: Option<u32>Width in pixels.
If only width is specified, Bing maintains the aspect ratio.
height: Option<u32>Height in pixels.
If only height is specified, Bing maintains the aspect ratio.
padding: Option<u32>Prevent white padding when the requested size exceeds the original.
Set to 0 to prevent padding.
crop: Option<CropMode>Crop mode.
Implementations